@@ -27,8 +27,10 @@ def rescue_main(
     custom_server: server = None,
     custom_unl: client = None,
 ) -> Block:
-    sender = candidate_block_hash["sender"]
-    logger.warning(
+    logger.info("Rescue operation is started")
+    logger.debug(f"First block: {block}")
+    sender = candidate_block_hash["hash"]["sender"]
+    logger.debug(
         f"Our block is not valid, the system will try to get true block from decentra_network.node {sender}"
     )
     block.dowload_true_block = sender
@@ -36,5 +38,7 @@ def rescue_main(
     the_server = server.Server if custom_server is None else custom_server
     the_unl_node = random.choice(
         unl_list) if custom_unl is None else custom_unl
+    logger.info(f"True block requested from {the_unl_node}")
     the_server.send_client(the_unl_node, {"action": "sendmefullblock"})
+    logger.debug(f"End block: {block}")
     return block
