@@ -14,8 +14,12 @@ logger = get_logger("CONSENSUS")
 
 def true_time(block: Block, return_result=False) -> bool:
     the_time = (block.genesis_time + block.block_time + (
-        (block.sequance_number + block.empty_block_number) * block.block_time))
-    if int(time.time()) >= the_time:
+        (block.sequence_number + block.empty_block_number) * block.block_time))
+    current_time = int(time.time())
+    logger.info("Consensus time control started")
+    logger.debug(f"current_time: {current_time}")
+    logger.debug(f"the_time: {the_time}")        
+    if current_time >= the_time:
         return True
     else:
         return False if return_result is False else the_time
