@@ -9,13 +9,12 @@ import hashlib
 import os
 import sys
 import time
-from cgitb import reset
 
 from speed_calculator import calculate
-
+sys.path.append(os.path.join(os.path.dirname(__file__), "..", "..", ".."))
 from decentra_network.lib.mix.merkle_root import MerkleTree
 
-sys.path.append(os.path.join(os.path.dirname(__file__), "..", "..", ".."))
+
 
 from decentra_network.accounts.account import Account
 from decentra_network.accounts.get_accounts import GetAccounts
@@ -45,8 +44,7 @@ class Blockshash_part_IO_Performance_Analyzer:
         blocks_in_a_day = seconds_in_a_day / self.block.block_time
 
         # how many blocks in a year
-        blocks_in_a_year = blocks_in_a_day * 365
-
+        blocks_in_a_year = (blocks_in_a_day * 365) // self.block.part_amount
         self.blocks_hash = [
             self.the_hash for i in range(int(blocks_in_a_year))
         ]
